==> hex_core-0.2.1.tar.gz: hex_tarball.md <==


# Module hex_tarball #
* [Data Types](#types)
* [Function Index](#index)
* [Function Details](#functions)

<a name="types"></a>

## Data Types ##




### <a name="type-checksum">checksum()</a> ###


<pre><code>
checksum() = binary()
</code></pre>




### <a name="type-contents">contents()</a> ###


<pre><code>
contents() = #{<a href="#type-filename">filename()</a> =&gt; binary()}
</code></pre>




### <a name="type-filename">filename()</a> ###


<pre><code>
filename() = string()
</code></pre>




### <a name="type-files">files()</a> ###


<pre><code>
files() = [<a href="#type-filename">filename()</a> | {<a href="#type-filename">filename()</a>, <a href="#type-filename">filename()</a>}] | <a href="#type-contents">contents()</a>
</code></pre>




### <a name="type-metadata">metadata()</a> ###


<pre><code>
metadata() = map()
</code></pre>




### <a name="type-tarball">tarball()</a> ###


<pre><code>
tarball() = binary()
</code></pre>

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#create-2">create/2</a></td><td>
Creates a package tarball.</td></tr><tr><td valign="top"><a href="#create_docs-1">create_docs/1</a></td><td>
Creates a docs tarball.</td></tr><tr><td valign="top"><a href="#format_checksum-1">format_checksum/1</a></td><td>
Returns base16-encoded representation of checksum.</td></tr><tr><td valign="top"><a href="#format_error-1">format_error/1</a></td><td>
Converts an error reason term to a human-readable error message string.</td></tr><tr><td valign="top"><a href="#unpack-2">unpack/2</a></td><td>
Unpacks a package tarball.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="create-2"></a>

### create/2 ###

<pre><code>
create(Metadata::<a href="#type-metadata">metadata()</a>, Files::<a href="#type-files">files()</a>) -&gt; {ok, {<a href="#type-tarball">tarball()</a>, <a href="#type-checksum">checksum()</a>}}
</code></pre>
<br />

Creates a package tarball.

Examples:

```
  > Metadata = #{<<"name">> => <<"foo">>, <<"version">> => <<"1.0.0">>},
  > Files = [{"src/foo.erl", <<"-module(foo).">>}],
  > {ok, {Tarball, Checksum}} = hex_tarball:create(Metadata, Files).
  > Tarball.
  <<86,69,...>>
  > Checksum.
  <<40,32,...>>
```

<a name="create_docs-1"></a>

### create_docs/1 ###

<pre><code>
create_docs(Files::<a href="#type-files">files()</a>) -&gt; {ok, {<a href="#type-tarball">tarball()</a>, <a href="#type-checksum">checksum()</a>}}
</code></pre>
<br />

Creates a docs tarball.

Examples:

```
  > Files = [{"doc/index.html", <<"Docs">>}],
  > {ok, {Tarball, Checksum}} = hex_tarball:create_docs(Files).
  > Tarball.
  %%=> <<86,69,...>>
  > Checksum.
  %%=> <<40,32,...>>
```

<a name="format_checksum-1"></a>

### format_checksum/1 ###

<pre><code>
format_checksum(Checksum::<a href="#type-checksum">checksum()</a>) -&gt; binary()
</code></pre>
<br />

Returns base16-encoded representation of checksum.

<a name="format_error-1"></a>

### format_error/1 ###

<pre><code>
format_error(X1::term()) -&gt; string()
</code></pre>
<br />

Converts an error reason term to a human-readable error message string.

<a name="unpack-2"></a>

### unpack/2 ###

<pre><code>
unpack(Tarball::<a href="#type-tarball">tarball()</a>, Output::memory) -&gt; {ok, #{checksum =&gt; <a href="#type-checksum">checksum()</a>, metadata =&gt; <a href="#type-metadata">metadata()</a>, contents =&gt; <a href="#type-contents">contents()</a>}} | {error, term()}
</code></pre>
<br />

Unpacks a package tarball.

Examples:

```
  > hex_tarball:unpack(Tarball, memory).
  {ok,#{checksum => <<...>>,
        contents => [{"src/foo.erl",<<"-module(foo).">>}],
        metadata => #{<<"name">> => <<"foo">>, ...}}}
  > hex_tarball:unpack(Tarball, "path/to/unpack").
  {ok,#{checksum => <<...>>,
        metadata => #{<<"name">> => <<"foo">>, ...}}}
```

==> hex_core-0.6.6.tar.gz: hex_tarball.md <==


# Module hex_tarball #
* [Data Types](#types)
* [Function Index](#index)
* [Function Details](#functions)

<a name="types"></a>

## Data Types ##




### <a name="type-checksum">checksum()</a> ###


<pre><code>
checksum() = binary()
</code></pre>




### <a name="type-contents">contents()</a> ###


<pre><code>
contents() = #{<a href="#type-filename">filename()</a> =&gt; binary()}
</code></pre>




### <a name="type-filename">filename()</a> ###


<pre><code>
filename() = string()
</code></pre>




### <a name="type-files">files()</a> ###


<pre><code>
files() = [{<a href="#type-filename">filename()</a>, <a href="#type-filename">filename()</a> | binary()}]
</code></pre>




### <a name="type-metadata">metadata()</a> ###


<pre><code>
metadata() = map()
</code></pre>




### <a name="type-tarball">tarball()</a> ###


<pre><code>
tarball() = binary()
</code></pre>

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#create-2">create/2</a></td><td>
Creates a package tarball.</td></tr><tr><td valign="top"><a href="#create_docs-1">create_docs/1</a></td><td>
Creates a docs tarball.</td></tr><tr><td valign="top"><a href="#format_checksum-1">format_checksum/1</a></td><td>
Returns base16-encoded representation of checksum.</td></tr><tr><td valign="top"><a href="#format_error-1">format_error/1</a></td><td>
Converts an error reason term to a human-readable error message string.</td></tr><tr><td valign="top"><a href="#unpack-2">unpack/2</a></td><td>
Unpacks a package tarball.</td></tr><tr><td valign="top"><a href="#unpack_docs-2">unpack_docs/2</a></td><td>
Unpacks a documentation tarball.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="create-2"></a>

### create/2 ###

<pre><code>
create(Metadata::<a href="#type-metadata">metadata()</a>, Files::<a href="#type-files">files()</a>) -&gt; {ok, {<a href="#type-tarball">tarball()</a>, <a href="#type-checksum">checksum()</a>}} | {error, term()}
</code></pre>
<br />

Creates a package tarball.

Returns the binary of the tarball the "inner checksum" and "outer checksum".
The inner checksum is deprecated in favor of the inner checksum.

Examples:

```
  > Metadata = #{<<"name">> => <<"foo">>, <<"version">> => <<"1.0.0">>},
  > Files = [{"src/foo.erl", <<"-module(foo).">>}],
  > hex_tarball:create(Metadata, Files).
  {ok, #{tarball => <<86,69,...>>,
         outer_checksum => <<40,32,...>>,
         inner_checksum => <<178,12,...>>}}
```

<a name="create_docs-1"></a>

### create_docs/1 ###

<pre><code>
create_docs(Files::<a href="#type-files">files()</a>) -&gt; {ok, <a href="#type-tarball">tarball()</a>}
</code></pre>
<br />

Creates a docs tarball.

Examples:

```
  > Files = [{"doc/index.html", <<"Docs">>}],
  > hex_tarball:create_docs(Files).
  {ok, <<86,69,...>>}
```

<a name="format_checksum-1"></a>

### format_checksum/1 ###

<pre><code>
format_checksum(Checksum::<a href="#type-checksum">checksum()</a>) -&gt; binary()
</code></pre>
<br />

Returns base16-encoded representation of checksum.

<a name="format_error-1"></a>

### format_error/1 ###

<pre><code>
format_error(X1::term()) -&gt; string()
</code></pre>
<br />

Converts an error reason term to a human-readable error message string.

<a name="unpack-2"></a>

### unpack/2 ###

<pre><code>
unpack(Tarball::<a href="#type-tarball">tarball()</a>, Output::memory) -&gt; {ok, #{checksum =&gt; <a href="#type-checksum">checksum()</a>, metadata =&gt; <a href="#type-metadata">metadata()</a>, contents =&gt; <a href="#type-contents">contents()</a>}} | {error, term()}
</code></pre>
<br />

Unpacks a package tarball.

Remember to verify the outer tarball checksum against the registry checksum
returned from `hex_repo:get_package(Config, Package)`.

Examples:

```
> hex_tarball:unpack(Tarball, memory).
{ok,#{outer_checksum => <<...>>,
contents => [{"src/foo.erl",<<"-module(foo).">>}],
metadata => #{<<"name">> => <<"foo">>, ...}}}

> hex_tarball:unpack(Tarball, "path/to/unpack").
{ok,#{outer_checksum => <<...>>,
metadata => #{<<"name">> => <<"foo">>, ...}}}`''

<a name="unpack_docs-2"></a>

### unpack_docs/2 ###

<pre><code>
unpack_docs(Tarball::<a href="#type-tarball">tarball()</a>, Output::memory) -&gt; {ok, <a href="#type-contents">contents()</a>} | {error, term()}
</code></pre>
<br />

Unpacks a documentation tarball.

Examples:

```
  > hex_tarball:unpack_docs(Tarball, memory).
  {ok, [{"index.html", <<"<!doctype>">>}, ...]}
  > hex_tarball:unpack_docs(Tarball, "path/to/unpack").
  ok
```
